==> jc-1.4.0.tar.gz: javax/print/attribute/standard/QueuedJobCount.h <==
// public final class javax.print.attribute.standard.QueuedJobCount

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 18f59a31666d35f javax_print_attribute_IntegerSyntax
// @dep_class 8593bfbc744077f0 javax_print_attribute_standard_QueuedJobCount

// header file dependencies
// @dep_header javax_print_attribute_IntegerSyntax

#include "javax/print/attribute/IntegerSyntax.h"

#ifndef _JC_javax_print_attribute_standard_QueuedJobCount_H_
#define _JC_javax_print_attribute_standard_QueuedJobCount_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$sub_refs	_jc_javax_print_attribute_standard_QueuedJobCount$sub_refs;
typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$sub_nonrefs	_jc_javax_print_attribute_standard_QueuedJobCount$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$refs	_jc_javax_print_attribute_standard_QueuedJobCount$refs;
typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$nonrefs	_jc_javax_print_attribute_standard_QueuedJobCount$nonrefs;
typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$object	_jc_javax_print_attribute_standard_QueuedJobCount$object;

typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$fields_struct	_jc_javax_print_attribute_standard_QueuedJobCount$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_QueuedJobCount$vmethods	_jc_javax_print_attribute_standard_QueuedJobCount$vmethods;
typedef const struct _jc_javax_print_attribute_standard_QueuedJobCount$vtable	_jc_javax_print_attribute_standard_QueuedJobCount$vtable;
typedef const struct _jc_javax_print_attribute_standard_QueuedJobCount$vtype	_jc_javax_print_attribute_standard_QueuedJobCount$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_QueuedJobCount$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24QueuedJobCount;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_QueuedJobCount$fields_struct _jc_javax_print_attribute_standard_QueuedJobCount$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_QueuedJobCount$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *, jint);

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_QueuedJobCount$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_QueuedJobCount$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_QueuedJobCount$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_QueuedJobCount$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_QueuedJobCount$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_QueuedJobCount$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_QueuedJobCount$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_QueuedJobCount$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_QueuedJobCount$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_IntegerSyntax$vmethods	javax_print_attribute_IntegerSyntax;
	_jc_javax_print_attribute_standard_QueuedJobCount$vmethods	javax_print_attribute_standard_QueuedJobCount;
};

// Vtype
struct _jc_javax_print_attribute_standard_QueuedJobCount$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_QueuedJobCount$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_QueuedJobCount$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_QueuedJobCount$refs {
    _jc_javax_print_attribute_standard_QueuedJobCount$sub_refs	javax_print_attribute_standard_QueuedJobCount;
    _jc_javax_print_attribute_IntegerSyntax$sub_refs	javax_print_attribute_IntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_QueuedJobCount$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_QueuedJobCount$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs	javax_print_attribute_IntegerSyntax;
    _jc_javax_print_attribute_standard_QueuedJobCount$sub_nonrefs	javax_print_attribute_standard_QueuedJobCount;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_QueuedJobCount$object {
	_jc_javax_print_attribute_standard_QueuedJobCount$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_QueuedJobCount$vtype	*vtype;
	_jc_javax_print_attribute_standard_QueuedJobCount$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_QueuedJobCount$vtype _jc_javax_print_attribute_standard_QueuedJobCount$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_QueuedJobCount, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_QueuedJobCount$class_object;

#endif	/* _JC_javax_print_attribute_standard_QueuedJobCount_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/QueuedJobCount.h <==
// public final class javax.print.attribute.standard.QueuedJobCount

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 18f59a31666d35f javax_print_attribute_IntegerSyntax
// @dep_class 8593bfbc744077f0 javax_print_attribute_standard_QueuedJobCount

// header file dependencies
// @dep_header javax_print_attribute_IntegerSyntax

#include "javax/print/attribute/IntegerSyntax.h"

#ifndef _JC_javax_print_attribute_standard_QueuedJobCount_H_
#define _JC_javax_print_attribute_standard_QueuedJobCount_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$sub_refs	_jc_javax_print_attribute_standard_QueuedJobCount$sub_refs;
typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$sub_nonrefs	_jc_javax_print_attribute_standard_QueuedJobCount$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$refs	_jc_javax_print_attribute_standard_QueuedJobCount$refs;
typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$nonrefs	_jc_javax_print_attribute_standard_QueuedJobCount$nonrefs;
typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$object	_jc_javax_print_attribute_standard_QueuedJobCount$object;

typedef struct _jc_javax_print_attribute_standard_QueuedJobCount$fields_struct	_jc_javax_print_attribute_standard_QueuedJobCount$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_QueuedJobCount$vmethods	_jc_javax_print_attribute_standard_QueuedJobCount$vmethods;
typedef const struct _jc_javax_print_attribute_standard_QueuedJobCount$vtable	_jc_javax_print_attribute_standard_QueuedJobCount$vtable;
typedef const struct _jc_javax_print_attribute_standard_QueuedJobCount$vtype	_jc_javax_print_attribute_standard_QueuedJobCount$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_QueuedJobCount$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24QueuedJobCount;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_QueuedJobCount$fields_struct _jc_javax_print_attribute_standard_QueuedJobCount$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_QueuedJobCount$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_QueuedJobCount$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_QueuedJobCount$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_QueuedJobCount$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_QueuedJobCount$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_QueuedJobCount$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_QueuedJobCount$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_QueuedJobCount$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_QueuedJobCount$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_QueuedJobCount$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_QueuedJobCount$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_IntegerSyntax$vmethods	javax_print_attribute_IntegerSyntax;
	_jc_javax_print_attribute_standard_QueuedJobCount$vmethods	javax_print_attribute_standard_QueuedJobCount;
};

// Vtype
struct _jc_javax_print_attribute_standard_QueuedJobCount$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_QueuedJobCount$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_QueuedJobCount$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_QueuedJobCount$refs {
    _jc_javax_print_attribute_standard_QueuedJobCount$sub_refs	javax_print_attribute_standard_QueuedJobCount;
    _jc_javax_print_attribute_IntegerSyntax$sub_refs	javax_print_attribute_IntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_QueuedJobCount$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_QueuedJobCount$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs	javax_print_attribute_IntegerSyntax;
    _jc_javax_print_attribute_standard_QueuedJobCount$sub_nonrefs	javax_print_attribute_standard_QueuedJobCount;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_QueuedJobCount$object {
	_jc_javax_print_attribute_standard_QueuedJobCount$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_QueuedJobCount$vtype	*vtype;
	_jc_javax_print_attribute_standard_QueuedJobCount$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_QueuedJobCount$vtype _jc_javax_print_attribute_standard_QueuedJobCount$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_QueuedJobCount, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_QueuedJobCount$class_object;

#endif	/* _JC_javax_print_attribute_standard_QueuedJobCount_H_ */
